summaryrefslogtreecommitdiffstats
path: root/src/input_common/drivers/tas_input.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/input_common/drivers/tas_input.h')
-rw-r--r--src/input_common/drivers/tas_input.h11
1 files changed, 3 insertions, 8 deletions
diff --git a/src/input_common/drivers/tas_input.h b/src/input_common/drivers/tas_input.h
index 82dc9d616..bfb37a638 100644
--- a/src/input_common/drivers/tas_input.h
+++ b/src/input_common/drivers/tas_input.h
@@ -138,21 +138,16 @@ private:
void LoadTasFiles();
/** Loads TAS file from the specified player
* @param player_index: player number where data is going to be stored
*/
- void LoadTasFile(size_t player_index);
+ void LoadTasFile(size_t player_index, size_t file_index);
/** Writes a TAS file from the recorded commands
* @param file_name: name of the file to be written
*/
void WriteTasFile(std::u8string file_name);
- /** Inverts the Y axis polarity
- * @param old: value of the axis
- * @return new value of the axis
- */
- TasAnalog FlipAxisY(TasAnalog old);
-
/**
* Parses a string containing the axis values. X and Y have a range from -32767 to 32767
* @param line: string containing axis values with the following format "x;y"
@@ -138,21 +138,16 @@ private:
void LoadTasFiles();
/** Loads TAS file from the specified player
- * @param player_index: player number where data is going to be stored
+ * @param player_index: player number to save the script
+ * @param file_index: script number of the file
*/